# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/logging/v1/log_group.proto\x12\x17yandex.cloud.logging.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x03\n\x08LogGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12=\n\x06labels\x18\x07 \x03(\x0b\x32-.yandex.cloud.logging.v1.LogGroup.LabelsEntry\x12\x38\n\x06status\x18\x08 \x01(\x0e\x32(.yandex.cloud.logging.v1.LogGroup.Status\x12\x33\n\x10retention_period\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0b\x64\x61ta_stream\x18\n \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x42\x62\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _LOGGROUP_LABELSENTRY._options = None
  _LOGGROUP_LABELSENTRY._serialized_options = b'8\001'
  _globals['_LOGGROUP']._serialized_start=134
  _globals['_LOGGROUP']._serialized_end=603
  _globals['_LOGGROUP_LABELSENTRY']._serialized_start=473
  _globals['_LOGGROUP_LABELSENTRY']._serialized_end=518
  _globals['_LOGGROUP_STATUS']._serialized_start=520
  _globals['_LOGGROUP_STATUS']._serialized_end=603
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import yandex.cloud.logging.v1.log_entry_pb2
import yandex.cloud.logging.v1.log_resource_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class WriteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    DEFAULTS_FIELD_NUMBER: builtins.int
    @property
    def destination(self) -> yandex.cloud.logging.v1.log_entry_pb2.Destination:
        """Log entries destination.

        See [Destination] for details.
        """

    @property
    def resource(self) -> yandex.cloud.logging.v1.log_resource_pb2.LogEntryResource:
        """Common resource (type, ID) specification for log entries."""

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.log_entry_pb2.IncomingLogEntry]:
        """List of log entries."""

    @property
    def defaults(self) -> yandex.cloud.logging.v1.log_entry_pb2.LogEntryDefaults:
        """Log entries defaults.

        See [LogEntryDefaults] for details.
        """

    def __init__(
        self,
        *,
        destination: yandex.cloud.logging.v1.log_entry_pb2.Destination | None = ...,
        resource: yandex.cloud.logging.v1.log_resource_pb2.LogEntryResource | None = ...,
        entries: collections.abc.Iterable[yandex.cloud.logging.v1.log_entry_pb2.IncomingLogEntry] | None = ...,
        defaults: yandex.cloud.logging.v1.log_entry_pb2.LogEntryDefaults | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["defaults", b"defaults", "destination", b"destination", "resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["defaults", b"defaults", "destination", b"destination", "entries", b"entries", "resource", b"resource"]) -> None: ...

global___WriteRequest = WriteRequest

@typing.final
class WriteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ErrorsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> google.rpc.status_pb2.Status: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: google.rpc.status_pb2.Status | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ERRORS_FIELD_NUMBER: builtins.int
    @property
    def errors(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, google.rpc.status_pb2.Status]:
        """Map<idx, status> of ingest failures.

        If entry with idx N is absent, it was ingested successfully.
        """

    def __init__(
        self,
        *,
        errors: collections.abc.Mapping[builtins.int, google.rpc.status_pb2.Status] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["errors", b"errors"]) -> None: ...

global___WriteResponse = WriteResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.foundation_models.v1.text_classification import text_classification_service_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2


class TextClassificationServiceStub(object):
    """Service for classifying text from input text.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Classify = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/Classify',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.FromString,
                )
        self.FewShotClassify = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/FewShotClassify',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.FromString,
                )


class TextClassificationServiceServicer(object):
    """Service for classifying text from input text.
    """

    def Classify(self, request, context):
        """RPC method for text classification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FewShotClassify(self, request, context):
        """RPC method for few-shot text classification.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextClassificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Classify': grpc.unary_unary_rpc_method_handler(
                    servicer.Classify,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.SerializeToString,
            ),
            'FewShotClassify': grpc.unary_unary_rpc_method_handler(
                    servicer.FewShotClassify,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextClassificationService(object):
    """Service for classifying text from input text.
    """

    @staticmethod
    def Classify(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/Classify',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.TextClassificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FewShotClassify(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.text_classification.TextClassificationService/FewShotClassify',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__classification_dot_text__classification__service__pb2.FewShotTextClassificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.monitoring.v3 import parametrization_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_parametrization__pb2
from yandex.cloud.monitoring.v3 import widget_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_widget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/monitoring/v3/dashboard.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30yandex/cloud/monitoring/v3/parametrization.proto\x1a\'yandex/cloud/monitoring/v3/widget.proto\"\xac\x04\n\tDashboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x16 \x01(\t\x12\x13\n\x0bmodified_by\x18\x17 \x01(\t\x12\x0c\n\x04name\x18\x18 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x19 \x01(\t\x12\x41\n\x06labels\x18\x1a \x03(\x0b\x32\x31.yandex.cloud.monitoring.v3.Dashboard.LabelsEntry\x12\r\n\x05title\x18\x1b \x01(\t\x12\x33\n\x07widgets\x18\x1c \x03(\x0b\x32\".yandex.cloud.monitoring.v3.Widget\x12\x44\n\x0fparametrization\x18\x1d \x01(\x0b\x32+.yandex.cloud.monitoring.v3.Parametrization\x12\x0c\n\x04\x65tag\x18\x1e \x01(\t\x12\x12\n\nmanaged_by\x18  \x01(\t\x12\x14\n\x0cmanaged_link\x18! \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\tcontainerJ\x04\x08\x04\x10\x14J\x04\x08\x02\x10\x03J\x04\x08\x1f\x10 Bk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.dashboard_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _DASHBOARD_LABELSENTRY._options = None
  _DASHBOARD_LABELSENTRY._serialized_options = b'8\001'
  _globals['_DASHBOARD']._serialized_start=199
  _globals['_DASHBOARD']._serialized_end=755
  _globals['_DASHBOARD_LABELSENTRY']._serialized_start=679
  _globals['_DASHBOARD_LABELSENTRY']._serialized_end=724
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/text_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v1 import primitives_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_primitives__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/vision/v1/text_detection.proto\x12\x19yandex.cloud.ai.vision.v1\x1a*yandex/cloud/ai/vision/v1/primitives.proto\"@\n\x0eTextAnnotation\x12.\n\x05pages\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.ai.vision.v1.Page\"\x8c\x01\n\x04Page\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x30\n\x06\x62locks\x18\x03 \x03(\x0b\x32 .yandex.cloud.ai.vision.v1.Block\x12\x33\n\x08\x65ntities\x18\x04 \x03(\x0b\x32!.yandex.cloud.ai.vision.v1.Entity\"$\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"q\n\x05\x42lock\x12\x38\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\".yandex.cloud.ai.vision.v1.Polygon\x12.\n\x05lines\x18\x02 \x03(\x0b\x32\x1f.yandex.cloud.ai.vision.v1.Line\"\x84\x01\n\x04Line\x12\x38\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\".yandex.cloud.ai.vision.v1.Polygon\x12.\n\x05words\x18\x02 \x03(\x0b\x32\x1f.yandex.cloud.ai.vision.v1.Word\x12\x12\n\nconfidence\x18\x03 \x01(\x01\"\xfc\x01\n\x04Word\x12\x38\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\".yandex.cloud.ai.vision.v1.Polygon\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\nconfidence\x18\x03 \x01(\x01\x12\x43\n\tlanguages\x18\x04 \x03(\x0b\x32\x30.yandex.cloud.ai.vision.v1.Word.DetectedLanguage\x12\x14\n\x0c\x65ntity_index\x18\x05 \x01(\x03\x1a=\n\x10\x44\x65tectedLanguage\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\x42\x65\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v1.text_detection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision'
  _globals['_TEXTANNOTATION']._serialized_start=121
  _globals['_TEXTANNOTATION']._serialized_end=185
  _globals['_PAGE']._serialized_start=188
  _globals['_PAGE']._serialized_end=328
  _globals['_ENTITY']._serialized_start=330
  _globals['_ENTITY']._serialized_end=366
  _globals['_BLOCK']._serialized_start=368
  _globals['_BLOCK']._serialized_end=481
  _globals['_LINE']._serialized_start=484
  _globals['_LINE']._serialized_end=616
  _globals['_WORD']._serialized_start=619
  _globals['_WORD']._serialized_end=871
  _globals['_WORD_DETECTEDLANGUAGE']._serialized_start=810
  _globals['_WORD_DETECTEDLANGUAGE']._serialized_end=871
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/llm/v1alpha/llm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/ai/llm/v1alpha/llm.proto\x12\x1byandex.cloud.ai.llm.v1alpha\x1a\x1egoogle/protobuf/wrappers.proto\"\x90\x01\n\x11GenerationOptions\x12\x17\n\x0fpartial_results\x18\x01 \x01(\x08\x12\x31\n\x0btemperature\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\nmax_tokens\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\">\n\x0b\x41lternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x12\x12\n\nnum_tokens\x18\x03 \x01(\x03\"%\n\x07Message\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"2\n\x05Token\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0f\n\x07special\x18\x03 \x01(\x08\x42\x66\n\x1fyandex.cloud.api.ai.llm.v1alphaZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/llm/v1alpha;llmb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.llm.v1alpha.llm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.ai.llm.v1alphaZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/llm/v1alpha;llm'
  _globals['_GENERATIONOPTIONS']._serialized_start=103
  _globals['_GENERATIONOPTIONS']._serialized_end=247
  _globals['_ALTERNATIVE']._serialized_start=249
  _globals['_ALTERNATIVE']._serialized_end=311
  _globals['_MESSAGE']._serialized_start=313
  _globals['_MESSAGE']._serialized_end=350
  _globals['_TOKEN']._serialized_start=352
  _globals['_TOKEN']._serialized_end=402
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.foundation_models.v1.text_generation import text_generation_service_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class TextGenerationServiceStub(object):
    """Service for text generation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Completion = channel.unary_stream(
                '/yandex.cloud.ai.foundation_models.v1.TextGenerationService/Completion',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionResponse.FromString,
                )


class TextGenerationServiceServicer(object):
    """Service for text generation.
    """

    def Completion(self, request, context):
        """A method for generating text completions in [synchronous mode](/docs/foundation-models/concepts/#working-mode).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextGenerationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Completion': grpc.unary_stream_rpc_method_handler(
                    servicer.Completion,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.TextGenerationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextGenerationService(object):
    """Service for text generation.
    """

    @staticmethod
    def Completion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.foundation_models.v1.TextGenerationService/Completion',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class TextGenerationAsyncServiceStub(object):
    """Service for asynchronous text generation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Completion = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.TextGenerationAsyncService/Completion',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class TextGenerationAsyncServiceServicer(object):
    """Service for asynchronous text generation.
    """

    def Completion(self, request, context):
        """A method for generating text completions in [asynchronous mode](/docs/foundation-models/concepts/#working-mode).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextGenerationAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Completion': grpc.unary_unary_rpc_method_handler(
                    servicer.Completion,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.TextGenerationAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextGenerationAsyncService(object):
    """Service for asynchronous text generation.
    """

    @staticmethod
    def Completion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.TextGenerationAsyncService/Completion',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class TokenizerServiceStub(object):
    """Service for tokenizing input content.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tokenize = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.TokenizerService/Tokenize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.FromString,
                )
        self.TokenizeCompletion = channel.unary_unary(
                '/yandex.cloud.ai.foundation_models.v1.TokenizerService/TokenizeCompletion',
                request_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.FromString,
                )


class TokenizerServiceServicer(object):
    """Service for tokenizing input content.
    """

    def Tokenize(self, request, context):
        """RPC method for tokenizing text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TokenizeCompletion(self, request, context):
        """RPC method for tokenizing content of CompletionRequest
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenizerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tokenize': grpc.unary_unary_rpc_method_handler(
                    servicer.Tokenize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.SerializeToString,
            ),
            'TokenizeCompletion': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenizeCompletion,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.foundation_models.v1.TokenizerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenizerService(object):
    """Service for tokenizing input content.
    """

    @staticmethod
    def Tokenize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.TokenizerService/Tokenize',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TokenizeCompletion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.foundation_models.v1.TokenizerService/TokenizeCompletion',
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.CompletionRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_text__generation_dot_text__generation__service__pb2.TokenizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/conversation_statistics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1.analysis import statistics_common_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_statistics__common__pb2
from yandex.cloud.speechsense.v1.analysis import speaker_statistics_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_analysis_dot_speaker__statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/speechsense/v1/analysis/conversation_statistics.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a<yandex/cloud/speechsense/v1/analysis/statistics_common.proto\x1a=yandex/cloud/speechsense/v1/analysis/speaker_statistics.proto\"\xcc\x01\n\x16\x43onversationStatistics\x12]\n\x17\x63onversation_boundaries\x18\x01 \x01(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.AudioSegmentBoundaries\x12S\n\x12speaker_statistics\x18\x02 \x03(\x0b\x32\x37.yandex.cloud.speechsense.v1.analysis.SpeakerStatisticsB\x9d\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x1b\x43onversationStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\033ConversationStatisticsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_CONVERSATIONSTATISTICS']._serialized_start=234
  _globals['_CONVERSATIONSTATISTICS']._serialized_end=438
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AuthProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDERS_FIELD_NUMBER: builtins.int
    @property
    def providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AuthProvider]: ...
    def __init__(
        self,
        *,
        providers: collections.abc.Iterable[global___AuthProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["providers", b"providers"]) -> None: ...

global___AuthProviders = AuthProviders

@typing.final
class AuthProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AuthProvider._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: AuthProvider._Type.ValueType  # 0
        NATIVE: AuthProvider._Type.ValueType  # 1
        SAML: AuthProvider._Type.ValueType  # 2
        """OPENID = 3;
        ANONYMOUS = 4;
        """

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: AuthProvider.Type.ValueType  # 0
    NATIVE: AuthProvider.Type.ValueType  # 1
    SAML: AuthProvider.Type.ValueType  # 2
    """OPENID = 3;
    ANONYMOUS = 4;
    """

    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HINT_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SAML_FIELD_NUMBER: builtins.int
    type: global___AuthProvider.Type.ValueType
    name: builtins.str
    order: builtins.int
    enabled: builtins.bool
    hidden: builtins.bool
    """selector ui settings"""
    description: builtins.str
    hint: builtins.str
    icon: builtins.str
    @property
    def saml(self) -> global___SamlSettings: ...
    def __init__(
        self,
        *,
        type: global___AuthProvider.Type.ValueType = ...,
        name: builtins.str = ...,
        order: builtins.int = ...,
        enabled: builtins.bool = ...,
        hidden: builtins.bool = ...,
        description: builtins.str = ...,
        hint: builtins.str = ...,
        icon: builtins.str = ...,
        saml: global___SamlSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["saml", b"saml", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "enabled", b"enabled", "hidden", b"hidden", "hint", b"hint", "icon", b"icon", "name", b"name", "order", b"order", "saml", b"saml", "settings", b"settings", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["settings", b"settings"]) -> typing.Literal["saml"] | None: ...

global___AuthProvider = AuthProvider

@typing.final
class SamlSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    IDP_METADATA_FILE_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    KIBANA_URL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_PRINCIPAL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_GROUPS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_EMAIL_FIELD_NUMBER: builtins.int
    ATTRIBUTE_DN_FIELD_NUMBER: builtins.int
    idp_entity_id: builtins.str
    idp_metadata_file: builtins.bytes
    sp_entity_id: builtins.str
    kibana_url: builtins.str
    attribute_principal: builtins.str
    attribute_groups: builtins.str
    attribute_name: builtins.str
    attribute_email: builtins.str
    attribute_dn: builtins.str
    def __init__(
        self,
        *,
        idp_entity_id: builtins.str = ...,
        idp_metadata_file: builtins.bytes = ...,
        sp_entity_id: builtins.str = ...,
        kibana_url: builtins.str = ...,
        attribute_principal: builtins.str = ...,
        attribute_groups: builtins.str = ...,
        attribute_name: builtins.str = ...,
        attribute_email: builtins.str = ...,
        attribute_dn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attribute_dn", b"attribute_dn", "attribute_email", b"attribute_email", "attribute_groups", b"attribute_groups", "attribute_name", b"attribute_name", "attribute_principal", b"attribute_principal", "idp_entity_id", b"idp_entity_id", "idp_metadata_file", b"idp_metadata_file", "kibana_url", b"kibana_url", "sp_entity_id", b"sp_entity_id"]) -> None: ...

global___SamlSettings = SamlSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PCITopology:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PCITopologyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PCITopology.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PCI_TOPOLOGY_UNSPECIFIED: _PCITopology.ValueType  # 0
    PCI_TOPOLOGY_V1: _PCITopology.ValueType  # 1
    PCI_TOPOLOGY_V2: _PCITopology.ValueType  # 2

class PCITopology(_PCITopology, metaclass=_PCITopologyEnumTypeWrapper): ...

PCI_TOPOLOGY_UNSPECIFIED: PCITopology.ValueType  # 0
PCI_TOPOLOGY_V1: PCITopology.ValueType  # 1
PCI_TOPOLOGY_V2: PCITopology.ValueType  # 2
global___PCITopology = PCITopology

@typing.final
class HardwareGeneration(google.protobuf.message.Message):
    """A set of features, specific to a particular Compute hardware generation.
    They are not necessary supported by every host OS or distro, thus they are fixed to an image
    and are applied to all instances created with it as their boot disk image.
    These features significantly determine how the instance is created, thus cannot be changed after the fact.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEGACY_FEATURES_FIELD_NUMBER: builtins.int
    GENERATION2_FEATURES_FIELD_NUMBER: builtins.int
    @property
    def legacy_features(self) -> global___LegacyHardwareFeatures: ...
    @property
    def generation2_features(self) -> global___Generation2HardwareFeatures: ...
    def __init__(
        self,
        *,
        legacy_features: global___LegacyHardwareFeatures | None = ...,
        generation2_features: global___Generation2HardwareFeatures | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["features", b"features", "generation2_features", b"generation2_features", "legacy_features", b"legacy_features"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["features", b"features", "generation2_features", b"generation2_features", "legacy_features", b"legacy_features"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["features", b"features"]) -> typing.Literal["legacy_features", "generation2_features"] | None: ...

global___HardwareGeneration = HardwareGeneration

@typing.final
class LegacyHardwareFeatures(google.protobuf.message.Message):
    """A first hardware generation, by default compatible with all legacy images.
    Allows switching to PCI_TOPOLOGY_V2 and back.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PCI_TOPOLOGY_FIELD_NUMBER: builtins.int
    pci_topology: global___PCITopology.ValueType
    def __init__(
        self,
        *,
        pci_topology: global___PCITopology.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pci_topology", b"pci_topology"]) -> None: ...

global___LegacyHardwareFeatures = LegacyHardwareFeatures

@typing.final
class Generation2HardwareFeatures(google.protobuf.message.Message):
    """A second hardware generation, which by default assumes PCI_TOPOLOGY_V2
    and UEFI boot (with UEFI related features).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Generation2HardwareFeatures = Generation2HardwareFeatures



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/rule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/serverless/eventrouter/v1/rule.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe4\x04\n\x04Rule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12H\n\x06labels\x18\x08 \x03(\x0b\x32\x38.yandex.cloud.serverless.eventrouter.v1.Rule.LabelsEntry\x12>\n\x06\x66ilter\x18\x0b \x01(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.Filter\x12H\n\x07targets\x18\x0c \x03(\x0b\x32..yandex.cloud.serverless.eventrouter.v1.TargetB\x07\x82\xc8\x31\x03\x31-5\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x43\n\x06status\x18\x0e \x01(\x0e\x32\x33.yandex.cloud.serverless.eventrouter.v1.Rule.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"<\n\x06\x46ilter\x12\x1f\n\tjq_filter\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1024H\x00\x42\x11\n\tcondition\x12\x04\xc0\xc1\x31\x01\"I\n\x0bTransformer\x12%\n\x0ejq_transformer\x18\x01 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536H\x00\x42\x13\n\x0btransformer\x12\x04\xc0\xc1\x31\x01\"\x8a\x08\n\x06Target\x12@\n\x03yds\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.YdsTargetH\x00\x12@\n\x03ymq\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.serverless.eventrouter.v1.YmqTargetH\x00\x12J\n\x08\x66unction\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.serverless.eventrouter.v1.FunctionTargetH\x00\x12L\n\tcontainer\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.ContainerTargetH\x00\x12g\n\x14gateway_ws_broadcast\x18\x05 \x01(\x0b\x32G.yandex.cloud.serverless.eventrouter.v1.GatewayWebsocketBroadcastTargetH\x00\x12H\n\x07logging\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.LoggingTargetH\x00\x12J\n\x08workflow\x18\x07 \x01(\x0b\x32\x36.yandex.cloud.serverless.eventrouter.v1.WorkflowTargetH\x00\x12H\n\x0btransformer\x18\x32 \x01(\x0b\x32\x33.yandex.cloud.serverless.eventrouter.v1.Transformer\x12M\n\x0eretry_settings\x18\x33 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.RetrySettings\x12T\n\x11\x64\x65\x61\x64_letter_queue\x18\x34 \x01(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.PutQueueMessageH\x01\x12\x45\n\x06status\x18\x36 \x01(\x0e\x32\x35.yandex.cloud.serverless.eventrouter.v1.Target.Status\"\x81\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x16\n\x12RESOURCE_NOT_FOUND\x10\x03\x12\x15\n\x11PERMISSION_DENIED\x10\x04\x12\x15\n\x11SUBJECT_NOT_FOUND\x10\x05\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\x42\r\n\x0b\x64\x65\x61\x64_letterJ\x04\x08\x08\x10\x32J\x04\x08\x35\x10\x36\"h\n\tYdsTarget\x12\x16\n\x08\x64\x61tabase\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bstream_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"N\n\tYmqTarget\x12\x17\n\tqueue_arn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xbe\x01\n\x0e\x46unctionTarget\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12$\n\x12service_account_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\xd7\x01\n\x0f\x43ontainerTarget\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x15\x63ontainer_revision_id\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12$\n\x12service_account_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\xd0\x01\n\x1fGatewayWebsocketBroadcastTarget\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettings\"\x8f\x01\n\rLoggingTarget\x12 \n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=63H\x00\x12\x1d\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=63H\x00\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50B\x13\n\x0b\x64\x65stination\x12\x04\xc0\xc1\x31\x01\"\xb8\x01\n\x0eWorkflowTarget\x12!\n\x0bworkflow_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x12service_account_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12M\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.serverless.eventrouter.v1.BatchSettingsJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"l\n\rRetrySettings\x12 \n\x0eretry_attempts\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12\x39\n\x0bmaximum_age\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=24h\"N\n\x0fPutQueueMessage\x12\x11\n\tqueue_arn\x18\x01 \x01(\t\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x88\x01\n\rBatchSettings\x12\x1d\n\tmax_count\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1f\n\tmax_bytes\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x30-262144\x12\x37\n\x06\x63utoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xe8\xc7\x31\x01\xfa\xc7\x31\x04<=1mB\x8a\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x04PERRZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.rule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\004PERRZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _RULE_LABELSENTRY._options = None
  _RULE_LABELSENTRY._serialized_options = b'8\001'
  _RULE.fields_by_name['targets']._options = None
  _RULE.fields_by_name['targets']._serialized_options = b'\202\3101\0031-5'
  _FILTER.oneofs_by_name['condition']._options = None
  _FILTER.oneofs_by_name['condition']._serialized_options = b'\300\3011\001'
  _FILTER.fields_by_name['jq_filter']._options = None
  _FILTER.fields_by_name['jq_filter']._serialized_options = b'\212\3101\006<=1024'
  _TRANSFORMER.oneofs_by_name['transformer']._options = None
  _TRANSFORMER.oneofs_by_name['transformer']._serialized_options = b'\300\3011\001'
  _TRANSFORMER.fields_by_name['jq_transformer']._options = None
  _TRANSFORMER.fields_by_name['jq_transformer']._serialized_options = b'\212\3101\007<=65536'
  _TARGET.oneofs_by_name['target']._options = None
  _TARGET.oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _YDSTARGET.fields_by_name['database']._options = None
  _YDSTARGET.fields_by_name['database']._serialized_options = b'\350\3071\001'
  _YDSTARGET.fields_by_name['stream_name']._options = None
  _YDSTARGET.fields_by_name['stream_name']._serialized_options = b'\350\3071\001'
  _YDSTARGET.fields_by_name['service_account_id']._options = None
  _YDSTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _YMQTARGET.fields_by_name['queue_arn']._options = None
  _YMQTARGET.fields_by_name['queue_arn']._serialized_options = b'\350\3071\001'
  _YMQTARGET.fields_by_name['service_account_id']._options = None
  _YMQTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FUNCTIONTARGET.fields_by_name['function_id']._options = None
  _FUNCTIONTARGET.fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FUNCTIONTARGET.fields_by_name['service_account_id']._options = None
  _FUNCTIONTARGET.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CONTAINERTARGET.fields_by_name['container_id']._options = None
  _CONTAINERTARGET.fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CONTAINERTARGET.fields_by_name['service_account_id']._options = None
  _CONTAINERTARGET.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['gateway_id']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['path']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['path']._serialized_options = b'\350\3071\001'
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['service_account_id']._options = None
  _GATEWAYWEBSOCKETBROADCASTTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LOGGINGTARGET.oneofs_by_name['destination']._options = None
  _LOGGINGTARGET.oneofs_by_name['destination']._serialized_options = b'\300\3011\001'
  _LOGGINGTARGET.fields_by_name['log_group_id']._options = None
  _LOGGINGTARGET.fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=63'
  _LOGGINGTARGET.fields_by_name['folder_id']._options = None
  _LOGGINGTARGET.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=63'
  _LOGGINGTARGET.fields_by_name['service_account_id']._options = None
  _LOGGINGTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _WORKFLOWTARGET.fields_by_name['workflow_id']._options = None
  _WORKFLOWTARGET.fields_by_name['workflow_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _WORKFLOWTARGET.fields_by_name['service_account_id']._options = None
  _WORKFLOWTARGET.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RETRYSETTINGS.fields_by_name['retry_attempts']._options = None
  _RETRYSETTINGS.fields_by_name['retry_attempts']._serialized_options = b'\372\3071\0040-10'
  _RETRYSETTINGS.fields_by_name['maximum_age']._options = None
  _RETRYSETTINGS.fields_by_name['maximum_age']._serialized_options = b'\372\3071\005<=24h'
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._options = None
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHSETTINGS.fields_by_name['max_count']._options = None
  _BATCHSETTINGS.fields_by_name['max_count']._serialized_options = b'\372\3071\0060-1000'
  _BATCHSETTINGS.fields_by_name['max_bytes']._options = None
  _BATCHSETTINGS.fields_by_name['max_bytes']._serialized_options = b'\372\3071\0100-262144'
  _BATCHSETTINGS.fields_by_name['cutoff']._options = None
  _BATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\350\3071\001\372\3071\004<=1m'
  _globals['_RULE']._serialized_start=190
  _globals['_RULE']._serialized_end=802
  _globals['_RULE_LABELSENTRY']._serialized_start=656
  _globals['_RULE_LABELSENTRY']._serialized_end=701
  _globals['_RULE_STATUS']._serialized_start=703
  _globals['_RULE_STATUS']._serialized_end=790
  _globals['_FILTER']._serialized_start=804
  _globals['_FILTER']._serialized_end=864
  _globals['_TRANSFORMER']._serialized_start=866
  _globals['_TRANSFORMER']._serialized_end=939
  _globals['_TARGET']._serialized_start=942
  _globals['_TARGET']._serialized_end=1976
  _globals['_TARGET_STATUS']._serialized_start=1804
  _globals['_TARGET_STATUS']._serialized_end=1933
  _globals['_YDSTARGET']._serialized_start=1978
  _globals['_YDSTARGET']._serialized_end=2082
  _globals['_YMQTARGET']._serialized_start=2084
  _globals['_YMQTARGET']._serialized_end=2162
  _globals['_FUNCTIONTARGET']._serialized_start=2165
  _globals['_FUNCTIONTARGET']._serialized_end=2355
  _globals['_CONTAINERTARGET']._serialized_start=2358
  _globals['_CONTAINERTARGET']._serialized_end=2573
  _globals['_GATEWAYWEBSOCKETBROADCASTTARGET']._serialized_start=2576
  _globals['_GATEWAYWEBSOCKETBROADCASTTARGET']._serialized_end=2784
  _globals['_LOGGINGTARGET']._serialized_start=2787
  _globals['_LOGGINGTARGET']._serialized_end=2930
  _globals['_WORKFLOWTARGET']._serialized_start=2933
  _globals['_WORKFLOWTARGET']._serialized_end=3117
  _globals['_RETRYSETTINGS']._serialized_start=3119
  _globals['_RETRYSETTINGS']._serialized_end=3227
  _globals['_PUTQUEUEMESSAGE']._serialized_start=3229
  _globals['_PUTQUEUEMESSAGE']._serialized_end=3307
  _globals['_BATCHSETTINGS']._serialized_start=3310
  _globals['_BATCHSETTINGS']._serialized_end=3446
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/s3_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/datasphere/v2/s3_service.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"R\n\x11\x41\x63tivateS3Request\x12\x1b\n\x05s3_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nproject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"T\n\x13\x44\x65\x61\x63tivateS3Request\x12\x1b\n\x05s3_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nproject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xd3\x02\n\tS3Service\x12\x9e\x01\n\x08\x41\x63tivate\x12-.yandex.cloud.datasphere.v2.ActivateS3Request\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/datasphere/v2/s3/activate:\x01*\x12\xa4\x01\n\nDeactivate\x12/.yandex.cloud.datasphere.v2.DeactivateS3Request\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!\"\x1c/datasphere/v2/s3/deactivate:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.s3_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _ACTIVATES3REQUEST.fields_by_name['s3_id']._options = None
  _ACTIVATES3REQUEST.fields_by_name['s3_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ACTIVATES3REQUEST.fields_by_name['project_id']._options = None
  _ACTIVATES3REQUEST.fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DEACTIVATES3REQUEST.fields_by_name['s3_id']._options = None
  _DEACTIVATES3REQUEST.fields_by_name['s3_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DEACTIVATES3REQUEST.fields_by_name['project_id']._options = None
  _DEACTIVATES3REQUEST.fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _S3SERVICE.methods_by_name['Activate']._options = None
  _S3SERVICE.methods_by_name['Activate']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/datasphere/v2/s3/activate:\001*'
  _S3SERVICE.methods_by_name['Deactivate']._options = None
  _S3SERVICE.methods_by_name['Deactivate']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002!\"\034/datasphere/v2/s3/deactivate:\001*'
  _globals['_ACTIVATES3REQUEST']._serialized_start=210
  _globals['_ACTIVATES3REQUEST']._serialized_end=292
  _globals['_DEACTIVATES3REQUEST']._serialized_start=294
  _globals['_DEACTIVATES3REQUEST']._serialized_end=378
  _globals['_S3SERVICE']._serialized_start=381
  _globals['_S3SERVICE']._serialized_end=720
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.type.dayofweek_pb2
import google.type.timeofday_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BackupSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAILY_BACKUP_SCHEDULE_FIELD_NUMBER: builtins.int
    WEEKLY_BACKUP_SCHEDULE_FIELD_NUMBER: builtins.int
    RECURRING_BACKUP_SCHEDULE_FIELD_NUMBER: builtins.int
    NEXT_EXECUTE_TIME_FIELD_NUMBER: builtins.int
    @property
    def daily_backup_schedule(self) -> global___DailyBackupSchedule: ...
    @property
    def weekly_backup_schedule(self) -> global___WeeklyBackupSchedule: ...
    @property
    def recurring_backup_schedule(self) -> global___RecurringBackupSchedule: ...
    @property
    def next_execute_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """output only field: when next backup will be executed
        using provided schedule.
        """

    def __init__(
        self,
        *,
        daily_backup_schedule: global___DailyBackupSchedule | None = ...,
        weekly_backup_schedule: global___WeeklyBackupSchedule | None = ...,
        recurring_backup_schedule: global___RecurringBackupSchedule | None = ...,
        next_execute_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["daily_backup_schedule", b"daily_backup_schedule", "next_execute_time", b"next_execute_time", "policy", b"policy", "recurring_backup_schedule", b"recurring_backup_schedule", "weekly_backup_schedule", b"weekly_backup_schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["daily_backup_schedule", b"daily_backup_schedule", "next_execute_time", b"next_execute_time", "policy", b"policy", "recurring_backup_schedule", b"recurring_backup_schedule", "weekly_backup_schedule", b"weekly_backup_schedule"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["policy", b"policy"]) -> typing.Literal["daily_backup_schedule", "weekly_backup_schedule", "recurring_backup_schedule"] | None: ...

global___BackupSchedule = BackupSchedule

@typing.final
class RecurringBackupSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    RECURRENCE_FIELD_NUMBER: builtins.int
    recurrence: builtins.str
    """An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how
    this backup reccurs.
    The FREQ values of MINUTELY, and SECONDLY are not supported.
    """
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the first recurrence."""

    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        recurrence: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["recurrence", b"recurrence", "start_time", b"start_time"]) -> None: ...

global___RecurringBackupSchedule = RecurringBackupSchedule

@typing.final
class DaysOfWeekBackupSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    EXECUTE_TIME_FIELD_NUMBER: builtins.int
    @property
    def days(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[google.type.dayofweek_pb2.DayOfWeek.ValueType]: ...
    @property
    def execute_time(self) -> google.type.timeofday_pb2.TimeOfDay: ...
    def __init__(
        self,
        *,
        days: collections.abc.Iterable[google.type.dayofweek_pb2.DayOfWeek.ValueType] | None = ...,
        execute_time: google.type.timeofday_pb2.TimeOfDay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execute_time", b"execute_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["days", b"days", "execute_time", b"execute_time"]) -> None: ...

global___DaysOfWeekBackupSchedule = DaysOfWeekBackupSchedule

@typing.final
class WeeklyBackupSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_OF_WEEK_FIELD_NUMBER: builtins.int
    @property
    def days_of_week(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaysOfWeekBackupSchedule]: ...
    def __init__(
        self,
        *,
        days_of_week: collections.abc.Iterable[global___DaysOfWeekBackupSchedule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["days_of_week", b"days_of_week"]) -> None: ...

global___WeeklyBackupSchedule = WeeklyBackupSchedule

@typing.final
class DailyBackupSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTE_TIME_FIELD_NUMBER: builtins.int
    @property
    def execute_time(self) -> google.type.timeofday_pb2.TimeOfDay: ...
    def __init__(
        self,
        *,
        execute_time: google.type.timeofday_pb2.TimeOfDay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execute_time", b"execute_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execute_time", b"execute_time"]) -> None: ...

global___DailyBackupSchedule = DailyBackupSchedule

@typing.final
class BackupSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BackupSettings._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: BackupSettings._Type.ValueType  # 0
        SYSTEM: BackupSettings._Type.ValueType  # 1
        USER: BackupSettings._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: BackupSettings.Type.ValueType  # 0
    SYSTEM: BackupSettings.Type.ValueType  # 1
    USER: BackupSettings.Type.ValueType  # 2

    class _StorageClass:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StorageClassEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BackupSettings._StorageClass.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STORAGE_CLASS_UNSPECIFIED: BackupSettings._StorageClass.ValueType  # 0
        STANDARD: BackupSettings._StorageClass.ValueType  # 1
        REDUCED_REDUNDANCY: BackupSettings._StorageClass.ValueType  # 2
        STANDARD_IA: BackupSettings._StorageClass.ValueType  # 3
        ONEZONE_IA: BackupSettings._StorageClass.ValueType  # 4
        INTELLIGENT_TIERING: BackupSettings._StorageClass.ValueType  # 5
        GLACIER: BackupSettings._StorageClass.ValueType  # 6
        DEEP_ARCHIVE: BackupSettings._StorageClass.ValueType  # 7
        OUTPOSTS: BackupSettings._StorageClass.ValueType  # 8

    class StorageClass(_StorageClass, metaclass=_StorageClassEnumTypeWrapper): ...
    STORAGE_CLASS_UNSPECIFIED: BackupSettings.StorageClass.ValueType  # 0
    STANDARD: BackupSettings.StorageClass.ValueType  # 1
    REDUCED_REDUNDANCY: BackupSettings.StorageClass.ValueType  # 2
    STANDARD_IA: BackupSettings.StorageClass.ValueType  # 3
    ONEZONE_IA: BackupSettings.StorageClass.ValueType  # 4
    INTELLIGENT_TIERING: BackupSettings.StorageClass.ValueType  # 5
    GLACIER: BackupSettings.StorageClass.ValueType  # 6
    DEEP_ARCHIVE: BackupSettings.StorageClass.ValueType  # 7
    OUTPOSTS: BackupSettings.StorageClass.ValueType  # 8

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BACKUP_SCHEDULE_FIELD_NUMBER: builtins.int
    BACKUP_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    SOURCE_PATHS_FIELD_NUMBER: builtins.int
    SOURCE_PATHS_TO_EXCLUDE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of backup settings"""
    description: builtins.str
    """human readable description."""
    type: global___BackupSettings.Type.ValueType
    storage_class: global___BackupSettings.StorageClass.ValueType
    @property
    def backup_schedule(self) -> global___BackupSchedule:
        """provide schedule. if empty, backup will be disabled."""

    @property
    def backup_time_to_live(self) -> google.protobuf.duration_pb2.Duration:
        """provide time to live of backup."""

    @property
    def source_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """provide a list of source paths. Each path can be directory, table or even database itself.
        Each directory (or database) will be traversed recursively and all childs of directory will be included to backup.
        By default, backup will be created for full database.
        """

    @property
    def source_paths_to_exclude(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """provide a list of paths to exclude from backup.
        Each path is a directory, table, or database.
        Each directory (or database) will be traversed recursively and all childs of directory will be excluded.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        backup_schedule: global___BackupSchedule | None = ...,
        backup_time_to_live: google.protobuf.duration_pb2.Duration | None = ...,
        source_paths: collections.abc.Iterable[builtins.str] | None = ...,
        source_paths_to_exclude: collections.abc.Iterable[builtins.str] | None = ...,
        type: global___BackupSettings.Type.ValueType = ...,
        storage_class: global___BackupSettings.StorageClass.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_schedule", b"backup_schedule", "backup_time_to_live", b"backup_time_to_live"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_schedule", b"backup_schedule", "backup_time_to_live", b"backup_time_to_live", "description", b"description", "name", b"name", "source_paths", b"source_paths", "source_paths_to_exclude", b"source_paths_to_exclude", "storage_class", b"storage_class", "type", b"type"]) -> None: ...

global___BackupSettings = BackupSettings

@typing.final
class BackupConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def backup_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackupSettings]: ...
    def __init__(
        self,
        *,
        backup_settings: collections.abc.Iterable[global___BackupSettings] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_settings", b"backup_settings"]) -> None: ...

global___BackupConfig = BackupConfig

@typing.final
class Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Backup._Status.ValueType  # 0
        CREATING: Backup._Status.ValueType  # 1
        READY: Backup._Status.ValueType  # 2
        ERROR: Backup._Status.ValueType  # 3
        CANCELLED: Backup._Status.ValueType  # 4

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """id of backup"""

    STATUS_UNSPECIFIED: Backup.Status.ValueType  # 0
    CREATING: Backup.Status.ValueType  # 1
    READY: Backup.Status.ValueType  # 2
    ERROR: Backup.Status.ValueType  # 3
    CANCELLED: Backup.Status.ValueType  # 4

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Backup._Type.ValueType  # 0
        SYSTEM: Backup._Type.ValueType  # 1
        """indicates that backup started by the system."""
        USER: Backup._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Backup.Type.ValueType  # 0
    SYSTEM: Backup.Type.ValueType  # 1
    """indicates that backup started by the system."""
    USER: Backup.Type.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BACKUP_SETTINGS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    """human readable backup name."""
    folder_id: builtins.str
    database_id: builtins.str
    description: builtins.str
    """description of backup."""
    status: global___Backup.Status.ValueType
    type: global___Backup.Type.ValueType
    size: builtins.int
    """size of backup in bytes."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """indicates when backup started."""

    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """indicates when backup completed."""

    @property
    def backup_settings(self) -> global___BackupSettings:
        """settings used to make backup."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        folder_id: builtins.str = ...,
        database_id: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___Backup.Status.ValueType = ...,
        backup_settings: global___BackupSettings | None = ...,
        type: global___Backup.Type.ValueType = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_settings", b"backup_settings", "completed_at", b"completed_at", "created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_settings", b"backup_settings", "completed_at", b"completed_at", "created_at", b"created_at", "database_id", b"database_id", "description", b"description", "folder_id", b"folder_id", "id", b"id", "name", b"name", "size", b"size", "started_at", b"started_at", "status", b"status", "type", b"type"]) -> None: ...

global___Backup = Backup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import hardware_generation_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_hardware__generation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/compute/v1/image.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31yandex/cloud/compute/v1/hardware_generation.proto\"\xc4\x04\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.compute.v1.Image.LabelsEntry\x12\x0e\n\x06\x66\x61mily\x18\x07 \x01(\t\x12\x14\n\x0cstorage_size\x18\x08 \x01(\x03\x12\x15\n\rmin_disk_size\x18\t \x01(\x03\x12\x13\n\x0bproduct_ids\x18\n \x03(\t\x12\x35\n\x06status\x18\x0b \x01(\x0e\x32%.yandex.cloud.compute.v1.Image.Status\x12\'\n\x02os\x18\x0c \x01(\x0b\x32\x1b.yandex.cloud.compute.v1.Os\x12\x0e\n\x06pooled\x18\r \x01(\x08\x12H\n\x13hardware_generation\x18\x0e \x01(\x0b\x32+.yandex.cloud.compute.v1.HardwareGeneration\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"j\n\x02Os\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .yandex.cloud.compute.v1.Os.Type\"4\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05LINUX\x10\x01\x12\x0b\n\x07WINDOWS\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _IMAGE_LABELSENTRY._options = None
  _IMAGE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_IMAGE']._serialized_start=149
  _globals['_IMAGE']._serialized_end=729
  _globals['_IMAGE_LABELSENTRY']._serialized_start=600
  _globals['_IMAGE_LABELSENTRY']._serialized_end=645
  _globals['_IMAGE_STATUS']._serialized_start=647
  _globals['_IMAGE_STATUS']._serialized_end=729
  _globals['_OS']._serialized_start=731
  _globals['_OS']._serialized_end=837
  _globals['_OS_TYPE']._serialized_start=785
  _globals['_OS_TYPE']._serialized_end=837
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.eventrouter.v1.rule_pb2
import yandex.cloud.serverless.eventrouter.v1.rule_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RuleServiceStub:
    """A set of methods for managing rules for serverless eventrouter."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.GetRuleRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule,
    ]
    """Returns the specified rules.
    To get the list of all available buses, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesResponse,
    ]
    """Retrieves the list of rules in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.CreateRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a rule in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.UpdateRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified rule."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DeleteRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified rule."""

    Enable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.EnableRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified rule."""

    Disable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DisableRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified rule."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified rule."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the rule."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified rule."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsResponse,
    ]
    """Lists operations for the specified rule."""

class RuleServiceAsyncStub:
    """A set of methods for managing rules for serverless eventrouter."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.GetRuleRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule,
    ]
    """Returns the specified rules.
    To get the list of all available buses, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesResponse,
    ]
    """Retrieves the list of rules in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.CreateRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a rule in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.UpdateRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified rule."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DeleteRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified rule."""

    Enable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.EnableRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified rule."""

    Disable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DisableRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified rule."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified rule."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the rule."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified rule."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsRequest,
        yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsResponse,
    ]
    """Lists operations for the specified rule."""

class RuleServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing rules for serverless eventrouter."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.GetRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule, collections.abc.Awaitable[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule]]:
        """Returns the specified rules.
        To get the list of all available buses, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesResponse, collections.abc.Awaitable[yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRulesResponse]]:
        """Retrieves the list of rules in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.CreateRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a rule in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.UpdateRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified rule."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DeleteRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified rule."""

    @abc.abstractmethod
    def Enable(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.EnableRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enables the specified rule."""

    @abc.abstractmethod
    def Disable(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.DisableRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disables the specified rule."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified rule."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the rule."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified rule."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.eventrouter.v1.rule_service_pb2.ListRuleOperationsResponse]]:
        """Lists operations for the specified rule."""

def add_RuleServiceServicer_to_server(servicer: RuleServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.ml_model_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetMlModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that the model belongs to."""
    ml_model_name: builtins.str
    """Name of the model to return.

    To get a model name make a [MlModelService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name"]) -> None: ...

global___GetMlModelRequest = GetMlModelRequest

@typing.final
class ListMlModelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that models belongs to."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListMlModelsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListMlModelsResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMlModelsRequest = ListMlModelsRequest

@typing.final
class ListMlModelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ML_MODELS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListMlModelsRequest.page_size], use `next_page_token` as the value
    for the [ListMlModelsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def ml_models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.ml_model_pb2.MlModel]:
        """List of models in the specified cluster."""

    def __init__(
        self,
        *,
        ml_models: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.ml_model_pb2.MlModel] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ml_models", b"ml_models", "next_page_token", b"next_page_token"]) -> None: ...

global___ListMlModelsResponse = ListMlModelsResponse

@typing.final
class CreateMlModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to create a model in.

    To get a cluster ID make a [ClusterService.List] request.
    """
    ml_model_name: builtins.str
    """Model name. The model name is one of the arguments of the modelEvaluate() function, which is used to call the model in ClickHouse."""
    type: yandex.cloud.mdb.clickhouse.v1.ml_model_pb2.MlModelType.ValueType
    """Type of the model."""
    uri: builtins.str
    """Model file URL. You can only use models stored in Object Storage."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
        type: yandex.cloud.mdb.clickhouse.v1.ml_model_pb2.MlModelType.ValueType = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name", "type", b"type", "uri", b"uri"]) -> None: ...

global___CreateMlModelRequest = CreateMlModelRequest

@typing.final
class CreateMlModelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that a model is being added to."""
    ml_model_name: builtins.str
    """Name of the the model that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name"]) -> None: ...

global___CreateMlModelMetadata = CreateMlModelMetadata

@typing.final
class UpdateMlModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to update the model in.

    To get a cluster ID make a [ClusterService.List] request.
    """
    ml_model_name: builtins.str
    """Name of the the model to update."""
    uri: builtins.str
    """The new model file URL. You can only use models stored in Object Storage."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name", "update_mask", b"update_mask", "uri", b"uri"]) -> None: ...

global___UpdateMlModelRequest = UpdateMlModelRequest

@typing.final
class UpdateMlModelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that contains the model being updated."""
    ml_model_name: builtins.str
    """Name of the the model that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name"]) -> None: ...

global___UpdateMlModelMetadata = UpdateMlModelMetadata

@typing.final
class DeleteMlModelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to delete the model in.

    To get a cluster ID make a [ClusterService.List] request.
    """
    ml_model_name: builtins.str
    """Name of the the model to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name"]) -> None: ...

global___DeleteMlModelRequest = DeleteMlModelRequest

@typing.final
class DeleteMlModelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ML_MODEL_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster that contains the model being deleted."""
    ml_model_name: builtins.str
    """Name of the the model that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        ml_model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "ml_model_name", b"ml_model_name"]) -> None: ...

global___DeleteMlModelMetadata = DeleteMlModelMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.host_type_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetHostTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_TYPE_ID_FIELD_NUMBER: builtins.int
    host_type_id: builtins.str
    """ID of the host type to return.

    To get a host type ID make a [HostTypeService.List] request.
    """
    def __init__(
        self,
        *,
        host_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_type_id", b"host_type_id"]) -> None: ...

global___GetHostTypeRequest = GetHostTypeRequest

@typing.final
class ListHostTypesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListHostTypesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListHostTypesResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHostTypesRequest = ListHostTypesRequest

@typing.final
class ListHostTypesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_TYPES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListHostTypesRequest.page_size], use `next_page_token` as the value
    for the [ListHostTypesRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def host_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.host_type_pb2.HostType]:
        """Lists host types."""

    def __init__(
        self,
        *,
        host_types: collections.abc.Iterable[yandex.cloud.compute.v1.host_type_pb2.HostType] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_types", b"host_types", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHostTypesResponse = ListHostTypesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ydb/v1/backup_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/ydb/v1/backup.proto\"q\n\x10ListPathsRequest\x12\x1f\n\tbackup_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\";\n\x11ListPathsResponse\x12\r\n\x05paths\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetBackupRequest\x12\x1f\n\tbackup_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x12ListBackupsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\\\n\x13ListBackupsResponse\x12,\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.ydb.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"(\n\x13\x44\x65leteBackupRequest\x12\x11\n\tbackup_id\x18\x01 \x01(\t\">\n\x14\x44\x65leteBackupMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t2\xf7\x07\n\rBackupService\x12n\n\x03Get\x12%.yandex.cloud.ydb.v1.GetBackupRequest\x1a\x1b.yandex.cloud.ydb.v1.Backup\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/ydb/v1/backups/{backup_id}\x12\x85\x01\n\tListPaths\x12%.yandex.cloud.ydb.v1.ListPathsRequest\x1a&.yandex.cloud.ydb.v1.ListPathsResponse\")\x82\xd3\xe4\x93\x02#\x12!/ydb/v1/backups/{backup_id}/paths\x12r\n\x04List\x12\'.yandex.cloud.ydb.v1.ListBackupsRequest\x1a(.yandex.cloud.ydb.v1.ListBackupsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/ydb/v1/backups\x12u\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\x12\xa4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xad\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xab\x01\n\x06\x44\x65lete\x12(.yandex.cloud.ydb.v1.DeleteBackupRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*-\n\x14\x44\x65leteBackupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1d*\x1b/ydb/v1/backups/{backup_id}BV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _LISTPATHSREQUEST.fields_by_name['backup_id']._options = None
  _LISTPATHSREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPATHSREQUEST.fields_by_name['page_size']._options = None
  _LISTPATHSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTPATHSREQUEST.fields_by_name['page_token']._options = None
  _LISTPATHSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _GETBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BACKUPSERVICE.methods_by_name['Get']._options = None
  _BACKUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\035\022\033/ydb/v1/backups/{backup_id}'
  _BACKUPSERVICE.methods_by_name['ListPaths']._options = None
  _BACKUPSERVICE.methods_by_name['ListPaths']._serialized_options = b'\202\323\344\223\002#\022!/ydb/v1/backups/{backup_id}/paths'
  _BACKUPSERVICE.methods_by_name['List']._options = None
  _BACKUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/ydb/v1/backups'
  _BACKUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _BACKUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty'
  _BACKUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _BACKUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty'
  _BACKUPSERVICE.methods_by_name['Delete']._options = None
  _BACKUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBackupMetadata\022\025google.protobuf.Empty\202\323\344\223\002\035*\033/ydb/v1/backups/{backup_id}'
  _globals['_LISTPATHSREQUEST']._serialized_start=268
  _globals['_LISTPATHSREQUEST']._serialized_end=381
  _globals['_LISTPATHSRESPONSE']._serialized_start=383
  _globals['_LISTPATHSRESPONSE']._serialized_end=442
  _globals['_GETBACKUPREQUEST']._serialized_start=444
  _globals['_GETBACKUPREQUEST']._serialized_end=495
  _globals['_LISTBACKUPSREQUEST']._serialized_start=497
  _globals['_LISTBACKUPSREQUEST']._serialized_end=598
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=600
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=692
  _globals['_DELETEBACKUPREQUEST']._serialized_start=694
  _globals['_DELETEBACKUPREQUEST']._serialized_end=734
  _globals['_DELETEBACKUPMETADATA']._serialized_start=736
  _globals['_DELETEBACKUPMETADATA']._serialized_end=798
  _globals['_BACKUPSERVICE']._serialized_start=801
  _globals['_BACKUPSERVICE']._serialized_end=1816
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v3/stt_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/stt/v3/stt_service.proto\x12\x10speechkit.stt.v3\x1a yandex/cloud/ai/stt/v3/stt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\";\n\x15GetRecognitionRequest\x12\"\n\x0coperation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502q\n\nRecognizer\x12\x63\n\x12RecognizeStreaming\x12\".speechkit.stt.v3.StreamingRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x00(\x01\x30\x01\x32\xb3\x02\n\x0f\x41syncRecognizer\x12\x9c\x01\n\rRecognizeFile\x12&.speechkit.stt.v3.RecognizeFileRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/stt/v3/recognizeFileAsync:\x01*\x12\x80\x01\n\x0eGetRecognition\x12\'.speechkit.stt.v3.GetRecognitionRequest\x1a#.speechkit.stt.v3.StreamingResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/stt/v3/getRecognition0\x01\x42\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.stt.v3.stt_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt'
  _GETRECOGNITIONREQUEST.fields_by_name['operation_id']._options = None
  _GETRECOGNITIONREQUEST.fields_by_name['operation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYNCRECOGNIZER.methods_by_name['RecognizeFile']._options = None
  _ASYNCRECOGNIZER.methods_by_name['RecognizeFile']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/stt/v3/recognizeFileAsync:\001*'
  _ASYNCRECOGNIZER.methods_by_name['GetRecognition']._options = None
  _ASYNCRECOGNIZER.methods_by_name['GetRecognition']._serialized_options = b'\202\323\344\223\002\030\022\026/stt/v3/getRecognition'
  _globals['_GETRECOGNITIONREQUEST']._serialized_start=231
  _globals['_GETRECOGNITIONREQUEST']._serialized_end=290
  _globals['_RECOGNIZER']._serialized_start=292
  _globals['_RECOGNIZER']._serialized_end=405
  _globals['_ASYNCRECOGNIZER']._serialized_start=408
  _globals['_ASYNCRECOGNIZER']._serialized_end=715
# @@protoc_insertion_point(module_scope)



import logging
import time
from datetime import datetime
from typing import TYPE_CHECKING, Optional, Type, Union

import grpc
from google.protobuf.empty_pb2 import Empty

from yandex.cloud.operation.operation_service_pb2 import GetOperationRequest
from yandex.cloud.operation.operation_service_pb2_grpc import OperationServiceStub
from yandexcloud._backoff import backoff_exponential_jittered_min_interval
from yandexcloud._retry_interceptor import RetryInterceptor
from yandexcloud.operations import (
    MetaType,
    OperationError,
    OperationResult,
    ResponseType,
)

if TYPE_CHECKING:
    from yandex.cloud.operation.operation_pb2 import Operation
    from yandexcloud._sdk import SDK


def operation_waiter(sdk: "SDK", operation_id: str, timeout: Optional[float]) -> "OperationWaiter":
    retriable_codes = (
        grpc.StatusCode.UNAVAILABLE,
        grpc.StatusCode.RESOURCE_EXHAUSTED,
        grpc.StatusCode.INTERNAL,
    )
    # withstand server downtime for ~3.4 minutes with an exponential backoff
    retry_interceptor = RetryInterceptor(
        max_retry_count=13,
        per_call_timeout=30,
        back_off_func=backoff_exponential_jittered_min_interval(),
        retriable_codes=retriable_codes,
    )
    operation_service = sdk.client(
        OperationServiceStub,
        interceptor=retry_interceptor,
    )
    return OperationWaiter(operation_id, operation_service, timeout)


def wait_for_operation(sdk: "SDK", operation_id: str, timeout: Optional[float]) -> Optional["Operation"]:
    waiter = operation_waiter(sdk, operation_id, timeout)
    for _ in waiter:
        time.sleep(1)
    return waiter.operation


def get_operation_result(
    sdk: "SDK",
    operation: "Operation",
    response_type: Optional[Type["ResponseType"]] = None,
    meta_type: Optional[Type["MetaType"]] = None,
    timeout: Optional[float] = None,
    logger: Optional[logging.Logger] = None,
) -> Union["OperationResult[ResponseType, MetaType]", "OperationError"]:
    if not logger:
        logger = logging.getLogger()
        logger.addHandler(logging.NullHandler())
    operation_result: OperationResult[ResponseType, MetaType] = OperationResult(operation)
    created_at = datetime.fromtimestamp(operation.created_at.seconds)
    message = (
        "Running Yandex.Cloud operation. ID: {id}. "
        "Description: {description}. Created at: {created_at}. "
        "Created by: {created_by}."
    )
    message = message.format(
        id=operation.id,
        description=operation.description,
        created_at=created_at,
        created_by=operation.created_by,
    )
    if meta_type and meta_type is not Empty:
        unpacked_meta = meta_type()
        operation.metadata.Unpack(unpacked_meta)
        operation_result.meta = unpacked_meta
        message += f" Meta: {unpacked_meta}."
    logger.info(message)
    result = wait_for_operation(sdk, operation.id, timeout=timeout)
    if result is None:
        return OperationError(message="Unexpected operation result", operation_result=OperationResult(operation))
    if result.error and result.error.code:
        error_message = (
            "Error Yandex.Cloud operation. ID: {id}. Error code: {code}. Details: {details}. Message: {message}."
        )
        error_message = error_message.format(
            id=result.id,
            code=result.error.code,
            details=result.error.details,
            message=result.error.message,
        )
        logger.error(error_message)
        raise OperationError(message=error_message, operation_result=OperationResult(operation))

    log_message = f"Done Yandex.Cloud operation. ID: {operation.id}."
    if response_type and response_type is not Empty:
        unpacked_response = response_type()
        result.response.Unpack(unpacked_response)
        operation_result.response = unpacked_response
        log_message += f" Response: {unpacked_response}."
    logger.info(log_message)
    return operation_result


class OperationWaiter:
    def __init__(self, operation_id: str, operation_service: "OperationServiceStub", timeout: Optional[float] = None):
        self.__operation: Optional["Operation"] = None
        self.__operation_id = operation_id
        self.__operation_service = operation_service
        self.__deadline = time.time() + timeout if timeout else None

    @property
    def operation(self) -> Optional["Operation"]:
        return self.__operation

    @property
    def done(self) -> bool:
        self.__operation = self.__operation_service.Get(GetOperationRequest(operation_id=self.__operation_id))
        return self.__operation is not None and self.__operation.done

    def __iter__(self) -> "OperationWaiter":
        return self

    def __next__(self) -> None:
        if self.done or self.__deadline is not None and time.time() >= self.__deadline:
            raise StopIteration()

    next = __next__  # for Python 2
